@@ -1,17 +1,20 @@
-# $Id: Twofish.pm,v 2.00 2001/04/29 23:15:55 ams Exp $
-# Copyright 2001 Abhijit Menon-Sen <ams@wiw.org>
+# $Id: Twofish.pm,v 2.12 2001/05/21 17:38:01 ams Exp $
+# Copyright 2001 Abhijit Menon-Sen <ams@toroid.org>
 
 package Crypt::Twofish;
 
 use strict;
 use Carp;
 use DynaLoader;
-use vars qw( @ISA $VERSION );
+use vars qw( @ISA $VERSION $XS_VERSION );
 
 @ISA = qw( DynaLoader );
-($VERSION) = q$Revision: 2.00 $ =~ /([\d.]+)/;
+$VERSION = '2.16_001';
+$XS_VERSION = $VERSION;
+$VERSION = eval $VERSION;
 
-bootstrap Crypt::Twofish $VERSION;
+
+bootstrap Crypt::Twofish $XS_VERSION;
 
 sub keysize   () { 16 }
 sub blocksize () { 16 }
@@ -21,7 +24,6 @@ sub new
     my ($class, $key) = @_;
 
     croak "Usage: ".__PACKAGE__."->new(\$key)" unless $key;
-
     return Crypt::Twofish::setup($key);
 }
 
@@ -29,7 +31,7 @@ sub encrypt
 {
     my ($self, $data) = @_;
 
-    croak "Usage: \$two->encrypt(\$data)" unless ref($self) && $data;
+    croak "Usage: \$cipher->encrypt(\$data)" unless ref($self) && $data;
     $self->crypt($data, $data, 0);
 }
 
@@ -37,7 +39,7 @@ sub decrypt
 {
     my ($self, $data) = @_;
 
-    croak "Usage: \$two->decrypt(\$data)" unless ref($self) && $data;
+    croak "Usage: \$cipher->decrypt(\$data)" unless ref($self) && $data;
     $self->crypt($data, $data, 1);
 }
 
@@ -82,11 +84,11 @@ Crypt::Twofish - The Twofish Encryption Algorithm
 
 use Crypt::Twofish;
 
-$two = Crypt::Twofish->new($key);
+$cipher = Crypt::Twofish->new($key);
 
-$ciphertext = $two->encrypt($plaintext);
+$ciphertext = $cipher->encrypt($plaintext);
 
-$plaintext  = $two->decrypt($ciphertext);
+$plaintext  = $cipher->decrypt($ciphertext);
 
 =head1 DESCRIPTION
 
@@ -98,7 +100,7 @@ and free for all uses, as described at
 This module implements Twofish encryption. It supports the Crypt::CBC
 interface, with the functions described below. It also provides an
 interface that is call-compatible with Crypt::Twofish 1.0, but its use
-is strongly discouraged.
+in new code is strongly discouraged.
 
 =head2 Functions
 
@@ -114,7 +116,7 @@ Returns the size (in bytes) of the key. Although the module understands
 128, 192, and 256-bit keys, it returns 16 for compatibility with
 Crypt::CBC.
 
-=item new($key, $rounds)
+=item new($key)
 
 This creates a new Crypt::Twofish object with the specified key (which
 should be 16, 24, or 32 bytes long).
@@ -139,16 +141,22 @@ Crypt::CBC, Crypt::Blowfish, Crypt::TEA
 
 =over 4
 
-=item Nishant Kakani wrote the first version of Crypt::Twofish (this
-version is a complete reimplementation).
+=item Nishant Kakani
+
+For writing Crypt::Twofish 1.0 (this version is a complete rewrite).
+
+=item Tony Cook
+
+For making the module work under Activeperl, testing on several
+platforms, and suggesting that I probe for features via %Config.
 
 =back
 
 =head1 AUTHOR
 
-Abhijit Menon-Sen <ams@wiw.org>
+Abhijit Menon-Sen <ams@toroid.org>
 
-Copyright 2001 Abhijit Menon-Sen. All rights reserved.
+Copyright 2001 Abhijit Menon-Sen.
 
-This is free software; you may redistribute and/or modify it under the
-same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
